# jaq

Extensions for multithreaded Python applications.

## Install

```sh
pip install jaq-alkasm
```

## Development

In a virtual environment:

```
$ poetry install
$ poetry check
$ poetry run pytest
$ poetry run black jaq
$ poetry run mypy jaq
```
